@@ -1,33 +1,34 @@
-import random
-
 import numpy as np
-import copy
+
+from python_ne.core.neural_network import activations
 
 
 class DenseLayer:
 
     def __init__(self, units, activation, input_shape=None, weights=(None, None,)):
         self.units = units
-        self.activation = activation
+        self.activation = activations.get_activation_from_str(activation)
         self.input_shape = input_shape
         self.weights, self.bias = weights
-        self.initialized = False
 
     def initialize(self):
-        if self.initialized:
+        if self.weights is not None and self.bias is not None:
             return
 
-        self.bias = np.array([random.uniform(-1, 1) for _ in range(self.units)])
+        self.bias = np.random.uniform(low=-1, high=1, size=(self.units,))
         # number os neurons of the prev layer and number of neurons of this layer, shape = (input_shape[0], units)
-        self.weights = np.array([[random.uniform(-1, 1) for j in range(self.units)] for i in range(self.input_shape[0])])
-        self.initialized = True
+        self.weights = np.random.uniform(low=-1, high=1, size=(self.input_shape[0], self.units))
 
     def feedforward(self, xs):
+        if xs.shape != self.input_shape:
+            raise Exception('Dense layer got an invalid input shape.' +
+                            f' Was expecting {self.input_shape} but got {xs.shape} instead')
+
         output = xs.dot(self.weights)
         return self.activation(output + self.bias)
 
     def get_weights(self):
-        return copy.copy(self.weights), copy.copy(self.bias)
+        return np.copy(self.weights), np.copy(self.bias)
 
     def set_weights(self, weights):
         self.weights, self.bias = weights
